pub struct SpanData {Show 14 fields
pub span_context: SpanContext,
pub parent_span_id: String,
pub span_kind: SpanKind,
pub name: String,
pub start_time: Datetime,
pub end_time: Datetime,
pub attributes: Vec<KeyValue>,
pub events: Vec<Event>,
pub links: Vec<Link>,
pub status: Status,
pub instrumentation_scope: InstrumentationScope,
pub dropped_attributes: u32,
pub dropped_events: u32,
pub dropped_links: u32,
}Expand description
The data associated with a span.
Fields
span_context: SpanContextSpan context.
parent_span_id: StringSpan parent id.
span_kind: SpanKindSpan kind.
name: StringSpan name.
start_time: DatetimeSpan start time.
end_time: DatetimeSpan end time.
attributes: Vec<KeyValue>Span attributes.
events: Vec<Event>Span events.
links: Vec<Link>Span Links.
status: StatusSpan status.
instrumentation_scope: InstrumentationScopeInstrumentation scope that produced this span.
dropped_attributes: u32Number of attributes dropped by the span due to limits being reached.
dropped_events: u32Number of events dropped by the span due to limits being reached.
dropped_links: u32Number of links dropped by the span due to limits being reached.